@@ -321,7 +321,7 @@ LaplacesDemon <- function(Model=NULL, Data=NULL, Adaptive=0,
                else rep(NA,3),
           DR=DR,
           Iterations=Iterations,
-          Minutes=as.vector(time2[3] - time1[3]) / 60,
+          Minutes=round(as.vector(time2[3] - time1[3]) / 60,2),
           Model=Model,
           Monitor=Mon,
           Parameters=LIV,
